@@ -105,10 +105,14 @@ class CLI(object):
 
         group.add_argument('-t', '--type-of-extraction', dest='type_of_extr',
                            default=None, type=str, nargs='?',
-                           choices=['pure-text', 'blocks', 'with-titles'],
+                           choices=['pure-text', 'blocks', 'with-titles', 'segments'],
                            help="Type of text extraction")
 
-        group.add_argument('-a', '--act', dest='act', default='all', type=str, 
+        group.add_argument('-seg', '--segmentation', dest='segmentation',
+                           default=False, type=bool,
+                           help="Activate the segmentation before the act extraction")
+
+        group.add_argument('-a', '--act', dest='act', default='all', type=str,
                            choices=act_choices, nargs='*',
                            help='Which acts to extract to CSV')
 
@@ -116,6 +120,9 @@ class CLI(object):
                            type=str, choices=['regex', 'ner'],
                            help="The backend to be used in CSV extraction")
 
+        group.add_argument('-x', '--xml', dest='xml', default=False, nargs='*',
+                            type=bool, help="Generate TeamTat XML Annotations")
+
     def parse(self):
         """Create parser and parse the arguments.
 
